@@ -6,13 +6,12 @@ from PySide.QtGui import *
 from PySide.QtMaemo5 import QMaemo5ValueButton, QMaemo5ListPickSelector
 
 # Some global variables
-Cps2GuiVersion = "0.0.1-1"
+Cps2GuiVersion = "0.0.1-2"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
 Cps2_KeyCfgFile = Home + '/.cps2emu/keyconfig.cfg'
 Cps2Gui_CfgFile = Home + '/.cps2-gui/cps2-gui.cfg'
-Cps2Gui_LogFile = Home + '/.cps2-gui/cps2-output.log'
 Cps2_GameFile = '/opt/cps2-gui/zipname.cps2'
 P1buttons = ""
 P2buttons = ""
@@ -161,7 +160,8 @@ class Ui_MainWindow(QMainWindow):
 	# but first, re-read all settings
         self.gui_opts = parse_config(self,Cps2Gui_CfgFile)
         if self.onesmutePushButton.isChecked():
-		ALL_OPTS="--no-sound "
+		ALL_OPTS="--sound "
+		#ALL_OPTS="--no-sound "  <--should be this
         else:  ALL_OPTS="--sound "
         if self.gui_opts["showfps"] == "false":
 		ALL_OPTS = ALL_OPTS + "--no-showfps "
